@@ -16,6 +16,7 @@ class DefaultConfig:
         'app.default_verbosity': 0,
         'app.email': '',
         'app.registries': ['cli.dogeek.me'],
+        'app.notify_new_version': True,
     }
 
 
@@ -31,7 +32,7 @@ templates_path.mkdir(parents=True, exist_ok=True)
 plugins_path: Path = (config.app_path / 'plugins')
 plugins_path.mkdir(parents=True, exist_ok=True)
 plugins_registry = JsonConfig('cli', 'registry.json')
-RESERVED_COMMANDS = ['config', 'env', 'plugins']
+RESERVED_COMMANDS = ('config', 'env', 'plugins', 'system')
 logs_path: Path = (config.app_path / 'logs')
 logs_path.mkdir(parents=True, exist_ok=True)
 tmp_dir: Path = (config.app_path / 'tmp')
